package com.hzya.frame.grpU8.nxproof.glkmxx.dao;


import com.hzya.frame.basedao.dao.IBaseDao;
import com.hzya.frame.grpU8.nxproof.glkmxx.entity.SenderGlKmxxEntity;

import java.util.List;

/**
 * (gl_kmxx: table)表数据库访问层
 *
 * @author makejava
 * @since 2024-06-20 10:01:13
 */
public interface ISenderGlKmxxDao extends IBaseDao<SenderGlKmxxEntity, String> {

    /**
     *
     * @content 查询科目信息  卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/20 10:11
     * **/
    List<SenderGlKmxxEntity> querySenderGlKmxxEntity(SenderGlKmxxEntity senderGlKmxxEntity);

    /**
     *
     * @content 保存科目信息到科目日志中 卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 16:12
     * **/
    SenderGlKmxxEntity saveSenderGlKmxxEntity(SenderGlKmxxEntity senderGlKmxxEntity);

    /**
     *
     * @content 更新科目信息到科目日志中  卫生院
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 16:12
     * **/
    SenderGlKmxxEntity updateSenderGlKmxxEntity(SenderGlKmxxEntity senderGlKmxxEntity);


    /**
     *
     * @content 查询科目信息  卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/20 10:11
     * **/
    List<SenderGlKmxxEntity> queryGlKmxxHealthBureau(SenderGlKmxxEntity senderGlKmxxEntity);

    /**
     *
     * @content 保存科目信息 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 16:12
     * **/
    SenderGlKmxxEntity saveGlKmxxHealthBureau(SenderGlKmxxEntity senderGlKmxxEntity );

    /**
     *
     * @content 更新科目信息 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/6/26 16:12
     * **/
    SenderGlKmxxEntity updateGlKmxxHealthBureau(SenderGlKmxxEntity senderGlKmxxEntity );

    /**
     *
     * @content 删除科目信息 卫生局
     * @Param
     * @Return
     * @Author hecan
     * @Date 2024/8/9 16:58
     * **/
    Integer deleteGlKmxxHealthBureau(SenderGlKmxxEntity senderGlKmxxEntity);



}

